@@ -20,6 +20,8 @@
 #ifndef _AUDACIOUS_MAIN_H
 #define _AUDACIOUS_MAIN_H
 
+#include <libaudcore/objects.h>
+
 /* dbus-server.c */
 #ifdef USE_DBUS
 
@@ -29,15 +31,16 @@ enum class StartupType {
     Unknown
 };
 
-StartupType dbus_server_init (void);
-void dbus_server_cleanup (void);
+StringBuf dbus_server_name ();
+StartupType dbus_server_init ();
+void dbus_server_cleanup ();
 
 #endif
 
 /* signals.c */
 #ifdef HAVE_SIGWAIT
-void signals_init_one (void);
-void signals_init_two (void);
+void signals_init_one ();
+void signals_init_two ();
 #endif
 
 #endif
