@@ -38,7 +38,6 @@
 #include "internal.h"
 
 #include <assert.h>
-#include <pthread.h>
 
 #include "audstrings.h"
 #include "hook.h"
@@ -48,25 +47,29 @@
 #include "output.h"
 #include "playlist-internal.h"
 #include "plugin.h"
-#include "plugins.h"
 #include "plugins-internal.h"
+#include "plugins.h"
 #include "runtime.h"
+#include "threads.h"
 
-struct PlaybackState {
+struct PlaybackState
+{
     bool playing = false;
     bool thread_running = false;
     int control_serial = 0;
     int playback_serial = 0;
 };
 
-struct PlaybackControl {
+struct PlaybackControl
+{
     bool paused = false;
     int seek = -1;
     int repeat_a = -1;
     int repeat_b = -1;
 };
 
-struct PlaybackInfo {
+struct PlaybackInfo
+{
     // set by playback_set_info
     int entry = -1;
     Tuple tuple;
@@ -78,7 +81,7 @@ struct PlaybackInfo {
     int time_offset = 0;
     int stop_time = -1;
 
-    ReplayGainInfo gain {};
+    ReplayGainInfo gain{};
     bool gain_valid = false;
 
     int bitrate = 0;
@@ -91,8 +94,8 @@ struct PlaybackInfo {
     String error_s;
 };
 
-static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
-static pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
+static aud::mutex mutex;
+static aud::condvar cond;
 
 static PlaybackState pb_state;
 static PlaybackControl pb_control;
@@ -102,258 +105,261 @@ static QueuedFunc end_queue;
 static bool song_finished = false;
 static int failed_entries = 0;
 
-static void lock ()
-    { pthread_mutex_lock (& mutex); }
-static void unlock ()
-    { pthread_mutex_unlock (& mutex); }
-
-static bool lock_if (bool (* test) ())
+// check that the playback thread is not lagging
+static bool in_sync(aud::mutex::holder &)
 {
-    lock ();
-    if (test ())
-        return true;
-
-    unlock ();
-    return false;
+    return pb_state.playing &&
+           pb_state.control_serial == pb_state.playback_serial;
 }
 
-// check that the playback thread is not lagging
-static bool in_sync ()
-    { return pb_state.playing && pb_state.control_serial == pb_state.playback_serial; }
-
 // check that the playback thread is not lagging and playback is "ready"
-static bool is_ready ()
-    { return in_sync () && pb_info.ready; }
+static bool is_ready(aud::mutex::holder & mh)
+{
+    return in_sync(mh) && pb_info.ready;
+}
 
 // called by playback_entry_set_tuple() to ensure that the tuple still applies
 // to the current song from the perspective of the main/playlist thread; the
 // check is necessary because playback_entry_set_tuple() is itself called from
 // the playback thread
-bool playback_check_serial (int serial)
+bool playback_check_serial(int serial)
 {
-    lock ();
-    bool okay = (pb_state.playing && pb_state.control_serial == serial);
-    unlock ();
-    return okay;
+    auto mh = mutex.take();
+    return pb_state.playing && pb_state.control_serial == serial;
 }
 
 // called from the playlist to update the tuple for the current song
-void playback_set_info (int entry, Tuple && tuple)
+void playback_set_info(int entry, Tuple && tuple)
 {
     // do nothing if the playback thread is lagging behind;
     // in that case, playback_set_info() will get called again anyway
-    if (! lock_if (in_sync))
+    auto mh = mutex.take();
+    if (!in_sync(mh))
         return;
 
-    if (tuple.valid () && tuple != pb_info.tuple)
+    if (tuple.valid() && tuple != pb_info.tuple)
     {
-        pb_info.tuple = std::move (tuple);
+        pb_info.tuple = std::move(tuple);
 
         // don't call "tuple change" before "playback ready"
-        if (is_ready ())
+        if (is_ready(mh))
         {
-            event_queue ("tuple change", nullptr);
-            output_set_tuple (pb_info.tuple);
+            event_queue("tuple change", nullptr);
+            output_set_tuple(pb_info.tuple);
         }
     }
 
-    String title = pb_info.tuple.get_str (Tuple::FormattedTitle);
+    String title = pb_info.tuple.get_str(Tuple::FormattedTitle);
     if (entry != pb_info.entry || title != pb_info.title)
     {
         pb_info.entry = entry;
         pb_info.title = title;
 
         // don't call "title change" before "playback ready"
-        if (is_ready ())
-            event_queue ("title change", nullptr);
+        if (is_ready(mh))
+            event_queue("title change", nullptr);
     }
-
-    unlock ();
 }
 
 // cleanup common to both playback_play() and playback_stop()
-static void playback_cleanup_locked ()
+static void playback_cleanup(aud::mutex::holder &)
 {
     pb_state.playing = false;
-    pb_control = PlaybackControl ();
-
-    // discard audio buffer if the song did not end on its own
-    if (! song_finished)
-        output_flush (0);
+    pb_control = PlaybackControl();
 
     // miscellaneous cleanup
-    end_queue.stop ();
+    end_queue.stop();
     song_finished = false;
 
-    event_queue_cancel ("playback ready");
-    event_queue_cancel ("playback pause");
-    event_queue_cancel ("playback unpause");
-    event_queue_cancel ("playback seek");
-    event_queue_cancel ("info change");
-    event_queue_cancel ("title change");
-    event_queue_cancel ("tuple change");
+    event_queue_cancel("playback ready");
+    event_queue_cancel("playback pause");
+    event_queue_cancel("playback unpause");
+    event_queue_cancel("playback seek");
+    event_queue_cancel("info change");
+    event_queue_cancel("title change");
+    event_queue_cancel("tuple change");
 
-    aud_set_bool (nullptr, "stop_after_current_song", false);
+    aud_set_bool("stop_after_current_song", false);
 }
 
 // main thread: stops playback when no more songs are to be played
-void playback_stop (bool exiting)
+void playback_stop(bool exiting)
 {
-    if (! pb_state.playing && ! exiting)
+    if (!pb_state.playing && !exiting)
         return;
 
-    lock ();
+    auto mh = mutex.take();
+
+    // discard audio buffer on a user-initiated stop
+    if (!song_finished || exiting)
+        output_flush(0, exiting);
 
     if (pb_state.playing)
-        playback_cleanup_locked ();
+        playback_cleanup(mh);
 
     if (pb_state.thread_running)
     {
-        // discard audio buffer if exiting
-        if (exiting)
-            output_flush (0, true);
-
         // signal playback thread to drain audio buffer
-        pb_state.control_serial ++;
-        pthread_cond_broadcast (& cond);
+        pb_state.control_serial++;
+        cond.notify_all();
 
         // wait for playback thread to finish if exiting
         while (exiting && pb_state.thread_running)
-            pthread_cond_wait (& cond, & mutex);
+            cond.wait(mh);
     }
 
-    unlock ();
-
     // miscellaneous cleanup
     failed_entries = 0;
 }
 
 // called from top-level event loop after playback finishes
-static void end_cb (void *)
+static void end_cb(void *)
 {
     song_finished = true;
-    hook_call ("playback end", nullptr);
+    hook_call("playback end", nullptr);
 
-    PlaylistEx playlist = Playlist::playing_playlist ();
+    PlaylistEx playlist = Playlist::playing_playlist();
 
-    auto do_stop = [playlist] ()
-    {
-        aud_drct_stop ();
-        playlist.set_position (playlist.get_position ());
+    auto do_stop = [playlist]() {
+        aud_drct_stop();
+        playlist.set_position(playlist.get_position());
     };
 
-    auto do_next = [playlist] ()
-    {
-        if (! playlist.next_song (aud_get_bool (nullptr, "repeat")))
+    auto do_next = [playlist]() {
+        if (!playlist.next_song(aud_get_bool("repeat")))
         {
-            playlist.set_position (-1);
-            hook_call ("playlist end reached", nullptr);
+            playlist.set_position(-1);
+            hook_call("playlist end reached", nullptr);
         }
     };
 
-    if (aud_get_bool (nullptr, "no_playlist_advance"))
+    if (aud_get_bool("no_playlist_advance"))
     {
         // we assume here that repeat is not enabled;
         // single-song repeats are handled in run_playback()
-        do_stop ();
+        do_stop();
     }
-    else if (aud_get_bool (nullptr, "stop_after_current_song"))
+    else if (aud_get_bool("stop_after_current_song"))
     {
-        do_stop ();
-        do_next ();
+        do_stop();
+        do_next();
     }
     else
     {
         // if 10 songs in a row have failed, or if the entire playlist
         // (for playlists less than 10 songs) has failed, stop trying
-        if (failed_entries < aud::min (playlist.n_entries (), 10))
-            do_next ();
+        if (failed_entries < aud::min(playlist.n_entries(), 10))
+            do_next();
         else
-            do_stop ();
+            do_stop();
     }
 }
 
 // helper, can be called from either main or playback thread
-static void request_seek_locked (int time)
+static void request_seek(aud::mutex::holder & mh, int time)
 {
     // set up "seek" command whether ready or not;
     // if not ready, it will take effect upon open_audio()
-    pb_control.seek = aud::max (0, time);
+    pb_control.seek = aud::max(0, time);
 
     // trigger seek immediately if ready
-    if (is_ready () && pb_info.length > 0)
+    if (is_ready(mh) && pb_info.length > 0)
     {
-        output_flush (aud::clamp (time, 0, pb_info.length));
-        event_queue ("playback seek", nullptr);
+        output_flush(aud::clamp(time, 0, pb_info.length));
+        event_queue("playback seek", nullptr);
     }
 }
 
 // playback thread helper
-static void run_playback ()
+static bool setup_playback(const DecodeInfo & dec)
 {
-    // due to mutex ordering, we cannot call into the playlist while locked
-    DecodeInfo dec = playback_entry_read (pb_state.playback_serial);
-
-    if (! lock_if (in_sync))
-        return;
+    auto mh = mutex.take();
+    if (!in_sync(mh))
+        return false;
 
     // for a cuesheet entry, determine the source filename
-    pb_info.filename = pb_info.tuple.get_str (Tuple::AudioFile);
-    if (! pb_info.filename)
-        pb_info.filename = std::move (dec.filename);
+    pb_info.filename = pb_info.tuple.get_str(Tuple::AudioFile);
+    if (!pb_info.filename)
+        pb_info.filename = std::move(dec.filename);
 
     // check that we have all the necessary data
-    if (! pb_info.filename || ! pb_info.tuple.valid () || ! dec.ip ||
-     (! dec.ip->input_info.keys[InputKey::Scheme] && ! dec.file))
+    if (!pb_info.filename || !pb_info.tuple.valid() || !dec.ip ||
+        (!dec.ip->input_info.keys[InputKey::Scheme] && !dec.file))
     {
         pb_info.error = true;
-        pb_info.error_s = std::move (dec.error);
-        unlock ();
-        return;
+        pb_info.error_s = std::move(dec.error);
+        return false;
     }
 
     // get various other bits of info from the tuple
-    pb_info.length = pb_info.tuple.get_int (Tuple::Length);
-    pb_info.time_offset = aud::max (0, pb_info.tuple.get_int (Tuple::StartTime));
-    pb_info.stop_time = aud::max (-1, pb_info.tuple.get_int (Tuple::EndTime) - pb_info.time_offset);
-    pb_info.gain = pb_info.tuple.get_replay_gain ();
-    pb_info.gain_valid = pb_info.tuple.has_replay_gain ();
+    pb_info.length = pb_info.tuple.get_int(Tuple::Length);
+    pb_info.time_offset = aud::max(0, pb_info.tuple.get_int(Tuple::StartTime));
+    pb_info.stop_time = aud::max(-1, pb_info.tuple.get_int(Tuple::EndTime) -
+                                         pb_info.time_offset);
+    pb_info.gain = pb_info.tuple.get_replay_gain();
+    pb_info.gain_valid = pb_info.tuple.has_replay_gain();
 
     // force initial seek if we are playing a segmented track
     if (pb_info.time_offset > 0 && pb_control.seek < 0)
         pb_control.seek = 0;
 
-    unlock ();
+    return true;
+}
+
+// playback thread helper
+static bool check_playback_repeat()
+{
+    auto mh = mutex.take();
+    if (!is_ready(mh))
+        return false;
+
+    // check whether we need to repeat
+    if (pb_control.repeat_a >= 0 ||
+        (aud_get_bool("repeat") && aud_get_bool("no_playlist_advance")))
+    {
+        // treat the repeat as a seek (takes effect at open_audio())
+        pb_control.seek = pb_control.repeat_a;
+
+        // force initial seek if we are playing a segmented track
+        if (pb_info.time_offset > 0 && pb_control.seek < 0)
+            pb_control.seek = 0;
+
+        event_queue("playback seek", nullptr);
+        pb_info.ended = false;
+        return true;
+    }
+
+    pb_info.ended = true;
+    return false;
+}
+
+// playback thread helper
+static void run_playback()
+{
+    // due to mutex ordering, we cannot call into the playlist while locked
+    DecodeInfo dec = playback_entry_read(pb_state.playback_serial);
+
+    if (!setup_playback(dec))
+        return;
 
     while (1)
     {
         // hand off control to input plugin
-        if (! dec.ip->play (pb_info.filename, dec.file))
+        if (!dec.ip->play(pb_info.filename, dec.file))
             pb_info.error = true;
 
         // close audio (no-op if it wasn't opened)
-        output_close_audio ();
+        output_close_audio();
 
         if (pb_info.error || pb_info.length <= 0)
             break;
 
-        if (! lock_if (in_sync))
-            break;
-
-        // check whether we need to repeat
-        pb_info.ended = (pb_control.repeat_a < 0 && ! (aud_get_bool (nullptr,
-         "repeat") && aud_get_bool (nullptr, "no_playlist_advance")));
-
-        if (! pb_info.ended)
-            request_seek_locked (pb_control.repeat_a);
-
-        unlock ();
-
-        if (pb_info.ended)
+        if (!check_playback_repeat())
             break;
 
         // rewind file pointer before repeating
-        if (! open_input_file (pb_info.filename, "r", dec.ip, dec.file, & pb_info.error_s))
+        if (!open_input_file(pb_info.filename, "r", dec.ip, dec.file,
+                             &pb_info.error_s))
         {
             pb_info.error = true;
             break;
@@ -362,36 +368,37 @@ static void run_playback ()
 }
 
 // playback thread helper
-static void finish_playback_locked ()
+static void finish_playback(aud::mutex::holder &)
 {
     // record any playback error that occurred
     if (pb_info.error)
     {
-        failed_entries ++;
+        failed_entries++;
 
         if (pb_info.error_s)
-            aud_ui_show_error (str_printf (_("Error playing %s:\n%s"),
-             (const char *) pb_info.filename, (const char *) pb_info.error_s));
+            aud_ui_show_error(str_printf(_("Error playing %s:\n%s"),
+                                         (const char *)pb_info.filename,
+                                         (const char *)pb_info.error_s));
         else
-            AUDERR ("Playback finished with error.\n");
+            AUDERR("Playback finished with error.\n");
     }
     else
         failed_entries = 0;
 
     // queue up function to start next song (or perform cleanup)
-    end_queue.queue (end_cb, nullptr);
+    end_queue.queue(end_cb, nullptr);
 }
 
 // playback thread
-static void * playback_thread (void *)
+static void playback_thread()
 {
-    lock ();
+    auto mh = mutex.take();
 
     while (1)
     {
         // wait for a command
         while (pb_state.control_serial == pb_state.playback_serial)
-            pthread_cond_wait (& cond, & mutex);
+            cond.wait(mh);
 
         // fetch the command (either "play" or "drain")
         bool play = pb_state.playing;
@@ -399,22 +406,23 @@ static void * playback_thread (void *)
         // update playback thread serial number
         pb_state.playback_serial = pb_state.control_serial;
 
-        unlock ();
+        mh.unlock();
 
         if (play)
-            run_playback ();
+            run_playback();
         else
-            output_drain ();
+            output_drain();
 
-        lock ();
+        mh.lock();
 
         if (play)
         {
-            // don't report errors or queue next song if another command is pending
-            if (in_sync ())
-                finish_playback_locked ();
+            // don't report errors or queue next song if another command is
+            // pending
+            if (in_sync(mh))
+                finish_playback(mh);
 
-            pb_info = PlaybackInfo ();
+            pb_info = PlaybackInfo();
         }
         else
         {
@@ -426,135 +434,129 @@ static void * playback_thread (void *)
 
     // signal the main thread that we are quitting
     pb_state.thread_running = false;
-    pthread_cond_broadcast (& cond);
-    unlock ();
-    return nullptr;
+    cond.notify_all();
 }
 
 // main thread: starts playback of a new song
-void playback_play (int seek_time, bool pause)
+void playback_play(int seek_time, bool pause)
 {
-    lock ();
+    auto mh = mutex.take();
+
+    // discard audio buffer unless progressing to the next song
+    if (!song_finished)
+        output_flush(0);
 
     if (pb_state.playing)
-        playback_cleanup_locked ();
+        playback_cleanup(mh);
 
     // set up "play" command
     pb_state.playing = true;
-    pb_state.control_serial ++;
+    pb_state.control_serial++;
     pb_control.paused = pause;
     pb_control.seek = (seek_time > 0) ? seek_time : -1;
 
     // start playback thread (or signal it if it's already running)
     if (pb_state.thread_running)
-        pthread_cond_broadcast (& cond);
+        cond.notify_all();
     else
     {
-        pthread_t thread;
-        pthread_create (& thread, nullptr, playback_thread, nullptr);
-        pthread_detach (thread);
+        std::thread(playback_thread).detach();
         pb_state.thread_running = true;
     }
-
-    unlock ();
 }
 
 // main thread
-EXPORT void aud_drct_pause ()
+EXPORT void aud_drct_pause()
 {
-    if (! pb_state.playing)
+    if (!pb_state.playing)
         return;
 
-    lock ();
+    auto mh = mutex.take();
 
     // set up "pause" command whether ready or not;
     // if not ready, it will take effect upon open_audio()
-    bool pause = ! pb_control.paused;
+    bool pause = !pb_control.paused;
     pb_control.paused = pause;
 
     // apply pause immediately if ready
-    if (is_ready ())
-        output_pause (pause);
+    if (is_ready(mh))
+        output_pause(pause);
 
-    event_queue (pause ? "playback pause" : "playback unpause", nullptr);
-
-    unlock ();
+    event_queue(pause ? "playback pause" : "playback unpause", nullptr);
 }
 
 // main thread
-EXPORT void aud_drct_seek (int time)
+EXPORT void aud_drct_seek(int time)
 {
-    if (! pb_state.playing)
+    if (!pb_state.playing)
         return;
 
-    lock ();
-    request_seek_locked (time);
-    unlock ();
+    auto mh = mutex.take();
+    request_seek(mh, time);
 }
 
-EXPORT void InputPlugin::open_audio (int format, int rate, int channels)
+EXPORT void InputPlugin::open_audio(int format, int rate, int channels)
 {
     // don't open audio if playback thread is lagging
-    if (! lock_if (in_sync))
+    auto mh = mutex.take();
+    if (!in_sync(mh))
         return;
 
-    if (! output_open_audio (pb_info.filename, pb_info.tuple, format, rate,
-     channels, aud::max (0, pb_control.seek)))
+    if (!output_open_audio(pb_info.filename, pb_info.tuple, format, rate,
+                           channels, aud::max(0, pb_control.seek),
+                           pb_control.paused))
     {
         pb_info.error = true;
-        pb_info.error_s = String (_("Invalid audio format"));
-        unlock ();
+        pb_info.error_s = String(_("Invalid audio format"));
         return;
     }
 
     if (pb_info.gain_valid)
-        output_set_replay_gain (pb_info.gain);
-    if (pb_control.paused)
-        output_pause (true);
+        output_set_replay_gain(pb_info.gain);
 
     pb_info.samplerate = rate;
     pb_info.channels = channels;
 
     if (pb_info.ready)
-        event_queue ("info change", nullptr);
+        event_queue("info change", nullptr);
     else
-        event_queue ("playback ready", nullptr);
+        event_queue("playback ready", nullptr);
 
     pb_info.ready = true;
-
-    unlock ();
 }
 
-EXPORT void InputPlugin::set_replay_gain (const ReplayGainInfo & gain)
+EXPORT void InputPlugin::set_replay_gain(const ReplayGainInfo & gain)
 {
-    lock ();
+    auto mh = mutex.take();
+
     pb_info.gain = gain;
     pb_info.gain_valid = true;
 
-    if (is_ready ())
-        output_set_replay_gain (gain);
-
-    unlock ();
+    if (is_ready(mh))
+        output_set_replay_gain(gain);
 }
 
-EXPORT void InputPlugin::write_audio (const void * data, int length)
+EXPORT void InputPlugin::write_audio(const void * data, int length)
 {
-    if (! lock_if (in_sync))
+    auto mh = mutex.take();
+    if (!in_sync(mh))
         return;
 
     // fetch A-B repeat settings
     int a = pb_control.repeat_a;
     int b = pb_control.repeat_b;
 
-    unlock ();
+    mh.unlock();
 
     // it's okay to call output_write_audio() even if we are no longer in sync,
     // since it will return immediately if output_flush() has been called
     int stop_time = (b >= 0) ? b : pb_info.stop_time;
-    if (output_write_audio (data, length, stop_time))
+    if (output_write_audio(data, length, stop_time))
         return;
 
-    if (! lock_if (in_sync))
+    mh.lock();
+
+    if (!in_sync(mh))
         return;
 
     // if we are still in sync, then one of the following happened:
@@ -564,179 +566,152 @@ EXPORT void InputPlugin::write_audio (const void * data, int length)
     if (pb_control.seek < 0)
     {
         if (b >= 0)
-            request_seek_locked (a);
+            request_seek(mh, a);
         else
             pb_info.ended = true;
     }
-
-    unlock ();
 }
 
-EXPORT Tuple InputPlugin::get_playback_tuple ()
+EXPORT Tuple InputPlugin::get_playback_tuple()
 {
-    lock ();
-    Tuple tuple = pb_info.tuple.ref ();
-    unlock ();
+    auto mh = mutex.take();
+    Tuple tuple = pb_info.tuple.ref();
 
     // tuples passed to us from input plugins do not have fallback fields
     // generated; for consistency, tuples passed back should not either
-    tuple.delete_fallbacks ();
+    tuple.delete_fallbacks();
     return tuple;
 }
 
-EXPORT void InputPlugin::set_playback_tuple (Tuple && tuple)
+EXPORT void InputPlugin::set_playback_tuple(Tuple && tuple)
 {
     // due to mutex ordering, we cannot call into the playlist while locked;
     // instead, playback_entry_set_tuple() calls back into first
     // playback_check_serial() and then eventually playback_set_info()
-    playback_entry_set_tuple (pb_state.playback_serial, std::move (tuple));
+    playback_entry_set_tuple(pb_state.playback_serial, std::move(tuple));
 }
 
-EXPORT void InputPlugin::set_stream_bitrate (int bitrate)
+EXPORT void InputPlugin::set_stream_bitrate(int bitrate)
 {
-    lock ();
+    auto mh = mutex.take();
     pb_info.bitrate = bitrate;
 
-    if (is_ready ())
-        event_queue ("info change", nullptr);
-
-    unlock ();
+    if (is_ready(mh))
+        event_queue("info change", nullptr);
 }
 
-EXPORT bool InputPlugin::check_stop ()
+EXPORT bool InputPlugin::check_stop()
 {
-    lock ();
-    bool stop = ! is_ready () || pb_info.ended || pb_info.error;
-    unlock ();
-    return stop;
+    auto mh = mutex.take();
+    return !is_ready(mh) || pb_info.ended || pb_info.error;
 }
 
-EXPORT int InputPlugin::check_seek ()
+EXPORT int InputPlugin::check_seek()
 {
-    lock ();
+    auto mh = mutex.take();
     int seek = -1;
 
-    if (is_ready () && pb_control.seek >= 0 && pb_info.length > 0)
+    if (is_ready(mh) && pb_control.seek >= 0 && pb_info.length > 0)
     {
-        seek = pb_info.time_offset + aud::min (pb_control.seek, pb_info.length);
+        seek = pb_info.time_offset + aud::min(pb_control.seek, pb_info.length);
         pb_control.seek = -1;
-        output_resume ();
+        output_resume();
     }
 
-    unlock ();
     return seek;
 }
 
 // thread-safe
-EXPORT bool aud_drct_get_playing ()
+EXPORT bool aud_drct_get_playing()
 {
-    lock ();
-    bool playing = pb_state.playing;
-    unlock ();
-    return playing;
+    auto mh = mutex.take();
+    return pb_state.playing;
 }
 
 // thread-safe
-EXPORT bool aud_drct_get_ready ()
+EXPORT bool aud_drct_get_ready()
 {
-    lock ();
-    bool ready = is_ready ();
-    unlock ();
-    return ready;
+    auto mh = mutex.take();
+    return is_ready(mh);
 }
 
 // thread-safe
-EXPORT bool aud_drct_get_paused ()
+EXPORT bool aud_drct_get_paused()
 {
-    lock ();
-    bool paused = pb_control.paused;
-    unlock ();
-    return paused;
+    auto mh = mutex.take();
+    return pb_control.paused;
 }
 
 // thread-safe
-EXPORT String aud_drct_get_title ()
+EXPORT String aud_drct_get_title()
 {
-    if (! lock_if (is_ready))
-        return String ();
+    auto mh = mutex.take();
+    if (!is_ready(mh))
+        return String();
 
-    String title = pb_info.title;
-    int entry = pb_info.entry;
-    int length = pb_info.length;
+    StringBuf prefix = aud_get_bool("show_numbers_in_pl")
+                           ? str_printf("%d. ", 1 + pb_info.entry)
+                           : StringBuf(0);
 
-    unlock ();
+    StringBuf time =
+        (pb_info.length > 0) ? str_format_time(pb_info.length) : StringBuf();
+    StringBuf suffix = time ? str_concat({" (", time, ")"}) : StringBuf(0);
 
-    StringBuf prefix = aud_get_bool (nullptr, "show_numbers_in_pl") ?
-     str_printf ("%d. ", 1 + entry) : StringBuf (0);
-
-    StringBuf time = (length > 0) ? str_format_time (length) : StringBuf ();
-    StringBuf suffix = time ? str_concat ({" (", time, ")"}) : StringBuf (0);
-
-    return String (str_concat ({prefix, title, suffix}));
+    return String(str_concat({prefix, pb_info.title, suffix}));
 }
 
 // thread-safe
-EXPORT Tuple aud_drct_get_tuple ()
+EXPORT Tuple aud_drct_get_tuple()
 {
-    lock ();
-    Tuple tuple = is_ready () ? pb_info.tuple.ref () : Tuple ();
-    unlock ();
-    return tuple;
+    auto mh = mutex.take();
+    return is_ready(mh) ? pb_info.tuple.ref() : Tuple();
 }
 
 // thread-safe
-EXPORT void aud_drct_get_info (int & bitrate, int & samplerate, int & channels)
+EXPORT void aud_drct_get_info(int & bitrate, int & samplerate, int & channels)
 {
-    lock ();
+    auto mh = mutex.take();
+    bool ready = is_ready(mh);
 
-    bool ready = is_ready ();
     bitrate = ready ? pb_info.bitrate : 0;
     samplerate = ready ? pb_info.samplerate : 0;
     channels = ready ? pb_info.channels : 0;
-
-    unlock ();
 }
 
 // thread-safe
-EXPORT int aud_drct_get_time ()
+EXPORT int aud_drct_get_time()
 {
-    lock ();
-    int time = is_ready () ? output_get_time () : 0;
-    unlock ();
-    return time;
+    auto mh = mutex.take();
+    return is_ready(mh) ? output_get_time() : 0;
 }
 
 // thread-safe
-EXPORT int aud_drct_get_length ()
+EXPORT int aud_drct_get_length()
 {
-    lock ();
-    int length = is_ready () ? pb_info.length : -1;
-    unlock ();
-    return length;
+    auto mh = mutex.take();
+    return is_ready(mh) ? pb_info.length : -1;
 }
 
 // main thread
-EXPORT void aud_drct_set_ab_repeat (int a, int b)
+EXPORT void aud_drct_set_ab_repeat(int a, int b)
 {
-    if (! pb_state.playing)
+    if (!pb_state.playing)
         return;
 
-    lock ();
+    auto mh = mutex.take();
 
     pb_control.repeat_a = a;
     pb_control.repeat_b = b;
 
-    if (b >= 0 && is_ready () && output_get_time () >= b)
-        request_seek_locked (a);
-
-    unlock ();
+    if (b >= 0 && is_ready(mh) && output_get_time() >= b)
+        request_seek(mh, a);
 }
 
 // thread-safe
-EXPORT void aud_drct_get_ab_repeat (int & a, int & b)
+EXPORT void aud_drct_get_ab_repeat(int & a, int & b)
 {
-    lock ();
+    auto mh = mutex.take();
+
     a = pb_control.repeat_a;
     b = pb_control.repeat_b;
-    unlock ();
 }
