@@ -20,7 +20,6 @@
 #include "internal.h"
 
 #include <assert.h>
-#include <pthread.h>
 #include <stdint.h>
 #include <string.h>
 
@@ -28,26 +27,27 @@
 #include "list.h"
 #include "mainloop.h"
 #include "output.h"
+#include "threads.h"
 
 #define INTERVAL 33 /* milliseconds */
 #define FRAMES_PER_NODE 512
 
 struct VisNode : public ListNode
 {
-    VisNode (int channels, int time) :
-        channels (channels),
-        time (time),
-        data (new float[channels * FRAMES_PER_NODE]) {}
+    VisNode(int channels, int time)
+        : channels(channels), time(time),
+          data(new float[channels * FRAMES_PER_NODE])
+    {
+    }
 
-    ~VisNode ()
-        { delete[] data; }
+    ~VisNode() { delete[] data; }
 
     const int channels;
     int time;
     float * data;
 };
 
-static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
+static aud::mutex mutex;
 static bool enabled = false;
 static bool playing = false, paused = false;
 static VisNode * current_node = nullptr;
@@ -56,23 +56,20 @@ static List<VisNode> vis_list;
 static List<VisNode> vis_pool;
 static QueuedFunc queued_clear;
 
-static void send_audio (void *)
+static void send_audio(void *)
 {
     /* call before locking mutex to avoid deadlock */
-    int outputted = output_get_raw_time ();
+    int outputted = output_get_raw_time();
 
-    pthread_mutex_lock (& mutex);
+    auto mh = mutex.take();
 
-    if (! enabled || ! playing || paused)
-    {
-        pthread_mutex_unlock (& mutex);
+    if (!enabled || !playing || paused)
         return;
-    }
 
     VisNode * node = nullptr;
     VisNode * next;
 
-    while ((next = vis_list.head ()))
+    while ((next = vis_list.head()))
     {
         /* If we are considering a node, stop searching and use it if it is the
          * most recent (that is, the next one is in the future).  Otherwise,
@@ -82,80 +79,72 @@ static void send_audio (void *)
             break;
 
         if (node)
-            vis_pool.prepend (node);
+            vis_pool.prepend(node);
 
         node = next;
-        vis_list.remove (node);
+        vis_list.remove(node);
     }
 
-    pthread_mutex_unlock (& mutex);
-
-    if (! node)
+    if (!node)
         return;
 
-    vis_send_audio (node->data, node->channels);
+    mh.unlock();
+    vis_send_audio(node->data, node->channels);
+    mh.lock();
 
-    pthread_mutex_lock (& mutex);
-    vis_pool.prepend (node);
-    pthread_mutex_unlock (& mutex);
+    vis_pool.prepend(node);
 }
 
-static void send_clear (void *)
-{
-    vis_send_clear ();
-}
+static void send_clear(void *) { vis_send_clear(); }
 
-static void flush_locked ()
+static void flush(aud::mutex::holder &)
 {
     delete current_node;
     current_node = nullptr;
 
-    vis_list.clear ();
-    vis_pool.clear ();
+    vis_list.clear();
+    vis_pool.clear();
 
     if (enabled)
-        queued_clear.queue (send_clear, nullptr);
+        queued_clear.queue(send_clear, nullptr);
 }
 
-void vis_runner_flush ()
+void vis_runner_flush()
 {
-    pthread_mutex_lock (& mutex);
-    flush_locked ();
-    pthread_mutex_unlock (& mutex);
+    auto mh = mutex.take();
+    flush(mh);
 }
 
-static void start_stop_locked (bool new_playing, bool new_paused)
+static void start_stop(aud::mutex::holder & mh, bool new_playing,
+                       bool new_paused)
 {
     playing = new_playing;
     paused = new_paused;
 
-    queued_clear.stop ();
+    queued_clear.stop();
 
-    if (! enabled || ! playing)
-        flush_locked ();
+    if (!enabled || !playing)
+        flush(mh);
 
-    if (enabled && playing && ! paused)
-        timer_add (TimerRate::Hz30, send_audio);
+    if (enabled && playing && !paused)
+        timer_add(TimerRate::Hz30, send_audio);
     else
-        timer_remove (TimerRate::Hz30, send_audio);
+        timer_remove(TimerRate::Hz30, send_audio);
 }
 
-void vis_runner_start_stop (bool new_playing, bool new_paused)
+void vis_runner_start_stop(bool new_playing, bool new_paused)
 {
-    pthread_mutex_lock (& mutex);
-    start_stop_locked (new_playing, new_paused);
-    pthread_mutex_unlock (& mutex);
+    auto mh = mutex.take();
+    start_stop(mh, new_playing, new_paused);
 }
 
-void vis_runner_pass_audio (int time, const Index<float> & data, int channels, int rate)
+void vis_runner_pass_audio(int time, const Index<float> & data, int channels,
+                           int rate)
 {
-    pthread_mutex_lock (& mutex);
+    auto mh = mutex.take();
 
-    if (! enabled || ! playing)
-    {
-        pthread_mutex_unlock (& mutex);
+    if (!enabled || !playing)
         return;
-    }
 
     /* We can build a single node from multiple calls; we can also build
      * multiple nodes from the same call.  If current_node is present, it was
@@ -166,7 +155,7 @@ void vis_runner_pass_audio (int time, const Index<float> & data, int channels, i
     while (1)
     {
         if (current_node)
-            assert (current_node->channels == channels);
+            assert(current_node->channels == channels);
         else
         {
             int node_time = time;
@@ -178,27 +167,27 @@ void vis_runner_pass_audio (int time, const Index<float> & data, int channels, i
              * queue, we are at the beginning of the song or had an underrun,
              * and we want to copy the earliest audio data we have. */
 
-            VisNode * tail = vis_list.tail ();
+            VisNode * tail = vis_list.tail();
             if (tail)
                 node_time = tail->time + INTERVAL;
 
-            at = channels * (int) ((int64_t) (node_time - time) * rate / 1000);
+            at = channels * (int)((int64_t)(node_time - time) * rate / 1000);
 
             if (at < 0)
                 at = 0;
-            if (at >= data.len ())
+            if (at >= data.len())
                 break;
 
-            current_node = vis_pool.head ();
+            current_node = vis_pool.head();
 
             if (current_node)
             {
-                assert (current_node->channels == channels);
-                vis_pool.remove (current_node);
+                assert(current_node->channels == channels);
+                vis_pool.remove(current_node);
                 current_node->time = node_time;
             }
             else
-                current_node = new VisNode (channels, node_time);
+                current_node = new VisNode(channels, node_time);
 
             current_frames = 0;
         }
@@ -208,24 +197,23 @@ void vis_runner_pass_audio (int time, const Index<float> & data, int channels, i
          * wait for more data to be passed in the next call.  If we do fill the
          * node, we loop and start building a new one. */
 
-        int copy = aud::min (data.len () - at, channels * (FRAMES_PER_NODE - current_frames));
-        memcpy (current_node->data + channels * current_frames, & data[at], sizeof (float) * copy);
+        int copy = aud::min(data.len() - at,
+                            channels * (FRAMES_PER_NODE - current_frames));
+        memcpy(current_node->data + channels * current_frames, &data[at],
+               sizeof(float) * copy);
         current_frames += copy / channels;
 
         if (current_frames < FRAMES_PER_NODE)
             break;
 
-        vis_list.append (current_node);
+        vis_list.append(current_node);
         current_node = nullptr;
     }
-
-    pthread_mutex_unlock (& mutex);
 }
 
-void vis_runner_enable (bool enable)
+void vis_runner_enable(bool enable)
 {
-    pthread_mutex_lock (& mutex);
+    auto mh = mutex.take();
     enabled = enable;
-    start_stop_locked (playing, paused);
-    pthread_mutex_unlock (& mutex);
+    start_stop(mh, playing, paused);
 }
