@@ -20,8 +20,10 @@
 #include <string.h>
 
 #include <libaudcore/equalizer.h>
+#include <libaudcore/hook.h>
 #include <libaudcore/i18n.h>
 #include <libaudcore/index.h>
+#include <libaudcore/interface.h>
 #include <libaudcore/runtime.h>
 
 #include "internal.h"
@@ -65,11 +67,16 @@ static void select_all (void *, bool selected)
         item.selected = selected;
 }
 
+static void activate_preset (const EqualizerPreset & preset)
+{
+    aud_eq_apply_preset (preset);
+    aud_set_bool ("equalizer_active", true);
+}
+
 static void activate_row (void *, int row)
 {
     g_return_if_fail (row >= 0 && row < preset_list.len ());
-    aud_eq_apply_preset (preset_list[row].preset);
-    aud_set_bool (nullptr, "equalizer_active", true);
+    activate_preset (preset_list[row].preset);
 }
 
 static void focus_change (void *, int row)
@@ -124,6 +131,30 @@ static int find_by_name (const char * name)
     return -1;
 }
 
+static const EqualizerPreset * find_one_selected ()
+{
+    const EqualizerPreset * preset = nullptr;
+
+    for (PresetItem & item : preset_list)
+    {
+        if (item.selected)
+        {
+            if (preset)
+            {
+                preset = nullptr;
+                break;
+            }
+
+            preset = & item.preset;
+        }
+    }
+
+    if (! preset)
+        aud_ui_show_error (_("Please select one preset to export."));
+
+    return preset;
+}
+
 static void text_changed ()
 {
     const char * name = gtk_entry_get_text ((GtkEntry *) entry);
@@ -186,6 +217,20 @@ static void revert_changes ()
     gtk_widget_set_sensitive (revert, false);
 }
 
+static void do_save_file (void)
+{
+    auto preset = find_one_selected ();
+    if (preset)
+        eq_preset_save_file (* preset);
+}
+
+static void do_save_eqf (void)
+{
+    auto preset = find_one_selected ();
+    if (preset)
+        eq_preset_save_eqf (* preset);
+}
+
 static void cleanup_eq_preset_window ()
 {
     // also hide the preset browser window
@@ -209,14 +254,12 @@ static GtkWidget * create_menu_bar ()
 {
     static const AudguiMenuItem import_items[] = {
         MenuCommand (N_("Preset File ..."), nullptr, 0, (GdkModifierType) 0, eq_preset_load_file),
-        MenuCommand (N_("EQF File ..."), nullptr, 0, (GdkModifierType) 0, eq_preset_load_eqf),
-        MenuSep (),
-        MenuCommand (N_("Winamp Presets ..."), nullptr, 0, (GdkModifierType) 0, eq_preset_import_winamp)
+        MenuCommand (N_("EQF File ..."), nullptr, 0, (GdkModifierType) 0, eq_preset_load_eqf)
     };
 
     static const AudguiMenuItem export_items[] = {
-        MenuCommand (N_("Preset File ..."), nullptr, 0, (GdkModifierType) 0, eq_preset_save_file),
-        MenuCommand (N_("EQF File ..."), nullptr, 0, (GdkModifierType) 0, eq_preset_save_eqf)
+        MenuCommand (N_("Preset File ..."), nullptr, 0, (GdkModifierType) 0, do_save_file),
+        MenuCommand (N_("EQF File ..."), nullptr, 0, (GdkModifierType) 0, do_save_eqf)
     };
 
     static const AudguiMenuItem menus[] = {
@@ -309,8 +352,17 @@ static void merge_presets (const Index<EqualizerPreset> & presets)
         preset_list.remove_if (is_duplicate);
     }
 
+    /* deselect existing presets */
+    for (auto & item : preset_list)
+        item.selected = false;
+
+    /* append and select new presets */
     for (const EqualizerPreset & preset : presets)
-        preset_list.append (preset, false);
+        preset_list.append (preset, true);
+
+    /* if a single preset was imported, activate it */
+    if (presets.len () == 1)
+        activate_preset (presets[0]);
 }
 
 EXPORT void audgui_import_eq_presets (const Index<EqualizerPreset> & presets)
@@ -322,6 +374,7 @@ EXPORT void audgui_import_eq_presets (const Index<EqualizerPreset> & presets)
     audgui_list_delete_rows (list, 0, preset_list.len ());
     merge_presets (presets);
     audgui_list_insert_rows (list, 0, preset_list.len ());
+    audgui_list_set_focus (list, preset_list.len () - 1);
 
     changes_made = true;
     gtk_widget_set_sensitive (revert, true);
