@@ -1,6 +1,6 @@
 /*
  * prefs-window.cc
- * Copyright 2006-2014 William Pitcock, Tomasz Moń, Michael Färber, and
+ * Copyright 2006-2014 Ariadne Conill, Tomasz Moń, Michael Färber, and
  *                     John Lindgren
  *
  * Redistribution and use in source and binary forms, with or without
@@ -107,6 +107,7 @@ static const TitleFieldTag title_field_tags[] = {
     { N_("File name")   , "${file-name}" },
     { N_("File path")   , "${file-path}" },
     { N_("Date")        , "${date}" },
+    { N_("Description") , "${description}" },
     { N_("Year")        , "${year}" },
     { N_("Comment")     , "${comment}" },
     { N_("Codec")       , "${codec}" },
@@ -268,6 +269,16 @@ static const PreferencesWidget connectivity_page_widgets[] = {
     WidgetCheck (N_("Use authentication with proxy"),
         WidgetBool (0, "use_proxy_auth")),
     WidgetTable ({{proxy_auth_elements}},
+        WIDGET_CHILD),
+    WidgetCheck (N_("Use SOCKS proxy"),
+        WidgetBool (0, "socks_proxy")),
+    WidgetRadio (N_("SOCKS v4a"),
+        WidgetInt (0, "socks_type"),
+        {0},
+        WIDGET_CHILD),
+    WidgetRadio (N_("SOCKS v5"),
+        WidgetInt (0, "socks_type"),
+        {1},
         WIDGET_CHILD)
 };
 
@@ -350,7 +361,14 @@ static const PreferencesWidget advanced_page_widgets[] = {
     WidgetCheck (N_("Do not load metadata for songs until played"),
         WidgetBool (0, "metadata_on_play")),
     WidgetCheck (N_("Probe content of files with no recognized file name extension"),
-        WidgetBool (0, "slow_probe"))
+        WidgetBool (0, "slow_probe")),
+    WidgetLabel (N_("<b>Miscellaneous</b>")),
+    WidgetSpin (N_("Step forward/backward by:"),
+        WidgetInt (0, "step_size"),
+        {1, 60, 1, N_("seconds")}),
+    WidgetSpin (N_("Adjust volume by:"),
+        WidgetInt (0, "volume_delta"),
+        {1, 25, 1, N_("percent")})
 };
 
 #define TITLESTRING_NPRESETS 8
@@ -454,7 +472,7 @@ static void update_titlestring_cbox (GtkComboBox * cbox, const char * format)
 static void on_titlestring_entry_changed (GtkEntry * entry, GtkComboBox * cbox)
 {
     const char * format = gtk_entry_get_text (entry);
-    aud_set_str (nullptr, "generic_title_format", format);
+    aud_set_str ("generic_title_format", format);
     update_titlestring_cbox (cbox, format);
 }
 
@@ -536,7 +554,7 @@ static void create_titlestring_widgets (GtkWidget * * cbox, GtkWidget * * entry)
 
     * entry = gtk_entry_new ();
 
-    String format = aud_get_str (nullptr, "generic_title_format");
+    String format = aud_get_str ("generic_title_format");
     update_titlestring_cbox ((GtkComboBox *) * cbox, format);
     gtk_entry_set_text ((GtkEntry *) * entry, format);
 
