@@ -36,6 +36,9 @@ void infopopup_hide_now();
 void log_init();
 void log_cleanup();
 
+/* prefs-plugin.cc */
+void plugin_prefs_hide();
+
 /* util-qt.cc */
 class PopupWidget : public QWidget
 {
